summaryrefslogtreecommitdiffstats
path: root/kmail/kmfolder.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmfolder.h')
-rw-r--r--kmail/kmfolder.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmail/kmfolder.h b/kmail/kmfolder.h
index 82d586a2..abf0a2da 100644
--- a/kmail/kmfolder.h
+++ b/kmail/kmfolder.h
@@ -60,7 +60,7 @@ typedef TQValueList<TQ_UINT32> SerNumList;
*
* @section Accounts
* The accounts (of KMail) that are fed into the folder are
- * represented as the tqchildren of the folder. They are only stored here
+ * represented as the children of the folder. They are only stored here
* during runtime to have a reference for which accounts point to a
* specific folder.
*/
@@ -169,10 +169,10 @@ public:
/** Specify, that the folder can't contain mails. */
void setNoContent(bool aNoContent);
- /** Returns, if the folder can't have tqchildren */
+ /** Returns, if the folder can't have children */
bool noChildren() const;
- /** Specify, that the folder can't have tqchildren */
+ /** Specify, that the folder can't have children */
void setNoChildren(bool aNoChildren);
/** Read message at given index. Indexing starts at zero */
@@ -273,7 +273,7 @@ public:
contained by this folder */
int countUnreadRecursive();
/** Called by KMMsgBase::seStatus when status of a message has changed
required to keep the number unread messages variable current. */
void msgStatusChanged( const KMMsgStatus oldStatus,
const KMMsgStatus newStatus,
@@ -490,10 +490,10 @@ public:
int writeIndex( bool createEmptyIndex = false );
/** Set the status of the message at index @p idx to @p status. */
- void seStatus(int idx, KMMsgStatus status, bool toggle=false);
+ void setStatus(int idx, KMMsgStatus status, bool toggle=false);
/** Set the status of the message(s) in the TQValueList @p ids to @p status. */
- void seStatus(TQValueList<int>& ids, KMMsgStatus status, bool toggle=false);
+ void setStatus(TQValueList<int>& ids, KMMsgStatus status, bool toggle=false);
/** Icon related methods */
bool useCustomIcons() const { return mUseCustomIcons; }
@@ -273,7 +273,7 @@ public:
contained by this folder */
int countUnreadRecursive();
- /** Called by KMMsgBase::seStatus when status of a message has changed
+ /** Called by KMMsgBase::setStatus when status of a message has changed
required to keep the number unread messages variable current. */
void msgStatusChanged( const KMMsgStatus oldStatus,